/*
  +----------------------------------------------------------------------+
  | Prove for PHP                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 2010 Electronic Service Initiative, Ltd.               |
  +----------------------------------------------------------------------+
  |                                                                      |
  | This is commercial product and all rights are reserved.              |
  | Please contact Electronic Service Initiative, Ltd. for License.      |
  |                                                                      |
  | EMail: info@es-i.jp                                                  |
  |                                                                      |
  +----------------------------------------------------------------------+
  | Author: Yasuo Ohgaki <yasuo.ohgaki@es-i.jp>                          |
  +----------------------------------------------------------------------+
*/

/*
 * This program removes dirs/files with much less memory than "rm"
 */
#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <dirent.h>
#include <string.h>
#include <unistd.h>
#include <errno.h>


int remove_file(const char *path) {
	static int depth = 0;
	DIR *d;
	struct dirent *e;
	char buf[1024];
	int path_len = strlen(path);

	if (depth > 10) {
		printf("Too deep path %s\n", path);
		return 1;
	}

	if (!depth && !unlink(path)) {
		/* Plain file */
		printf("Removed file %s\n", path);
		return 0;
	}

	if (!(d = opendir(path))) {
		/* Assume it's a dir */
		printf("Failed to open dir %s  %s\n", path, strerror(errno));
		return 1;
	}
	while ((e = readdir(d))) {
		if (!strcmp(e->d_name, ".") || !strcmp(e->d_name, "..")) {
			continue;
		}
		if (path[path_len-1] == '/') {
			snprintf(buf, 1023, "%s%s", path, e->d_name);
		} else {
			snprintf(buf, 1023, "%s/%s", path, e->d_name);
		}
		if (unlink(buf)) {
			/* Unlink failed. Simply assume it's a dir */
			depth++;
			remove_file(buf);
			depth--;
		}
	}
	closedir(d);

	if (rmdir(path)) {
		printf("Failed to remove dir %s  %s\n", path, strerror(errno));
	} else {
		printf("Removed dir %s\n", path);
	}

	return 0;
}

int main(int argc, char *argv[])
{
	if (argc != 2) {
		printf("This program delete dir recursivly. Sepcify file/dir to remove.\n");
		printf("Usage: %s dirname\n", argv[0]);
		return 1;
	}
	return remove_file(argv[1]);
}

